"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const IconButton_1 = __importDefault(require("@material-ui/core/IconButton"));
const TextField_1 = __importDefault(require("@material-ui/core/TextField"));
const FirstPage_1 = __importDefault(require("@material-ui/icons/FirstPage"));
const LastPage_1 = __importDefault(require("@material-ui/icons/LastPage"));
const NavigateBefore_1 = __importDefault(require("@material-ui/icons/NavigateBefore"));
const NavigateNext_1 = __importDefault(require("@material-ui/icons/NavigateNext"));
const React = __importStar(require("react"));
const react_redux_1 = require("react-redux");
const store_1 = require("../../store");
// tslint:disable-next-line:no-var-requires
const debounce = require('lodash.debounce');
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
exports.mapStateToProps = (state) => {
    return {
        activePages: state.sensenetDocumentViewer.viewer.activePages,
        pageCount: state.sensenetDocumentViewer.documentState.document.pageCount,
        firstPage: state.sensenetDocumentViewer.localization.firstPage,
        previousPage: state.sensenetDocumentViewer.localization.previousPage,
        gotoPage: state.sensenetDocumentViewer.localization.gotoPage,
        nextPage: state.sensenetDocumentViewer.localization.nextPage,
        lastPage: state.sensenetDocumentViewer.localization.lastPage,
    };
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
exports.mapDispatchToProps = {
    setActivePages: store_1.setActivePages,
};
/**
 * Document widget component for paging
 */
class PagerComponent extends React.Component {
    constructor() {
        super(...arguments);
        /** the component state */
        this.state = { currentPage: this.props.activePages[0], lastPage: this.props.pageCount };
        this.setPage = debounce(() => {
            this.props.setActivePages([this.state.currentPage]);
        }, 200).bind(this);
    }
    /** creates a derived state from props */
    static getDerivedStateFromProps(nextProps, lastState) {
        return Object.assign({}, lastState, { currentPage: lastState.currentPage || nextProps.activePages[0], lastPage: nextProps.pageCount });
    }
    gotoPage(page) {
        let pageInt = typeof page === 'string' ? parseInt(page, 10) : page;
        if (!isNaN(pageInt)) {
            pageInt = Math.max(pageInt, 1);
            pageInt = Math.min(pageInt, this.props.pageCount);
            this.setState({
                currentPage: pageInt,
            });
            this.setPage();
        }
    }
    /**
     * renders the component
     */
    render() {
        return (React.createElement("div", { style: { display: 'inline-block' } },
            React.createElement(IconButton_1.default, { disabled: this.state.currentPage <= 1, title: this.props.firstPage, onClick: () => this.gotoPage(1), id: "FirstPage" },
                React.createElement(FirstPage_1.default, null)),
            React.createElement(IconButton_1.default, { disabled: this.state.currentPage <= 1, title: this.props.previousPage, onClick: () => this.gotoPage(this.props.activePages[0] - 1), id: "NavigateBefore" },
                React.createElement(NavigateBefore_1.default, null)),
            React.createElement(TextField_1.default, { title: this.props.gotoPage, value: this.state.currentPage, onChange: ev => this.gotoPage(ev.currentTarget.value), type: "number", required: true, InputLabelProps: {
                    shrink: true,
                }, inputProps: { min: 1, max: this.state.lastPage }, margin: "dense" }),
            React.createElement(IconButton_1.default, { disabled: this.state.currentPage >= this.state.lastPage, title: this.props.nextPage, color: 'primary', onClick: () => this.gotoPage(this.props.activePages[0] + 1), id: "NavigateNext" },
                React.createElement(NavigateNext_1.default, null)),
            React.createElement(IconButton_1.default, { disabled: this.state.currentPage >= this.state.lastPage, title: this.props.lastPage, onClick: () => this.gotoPage(this.state.lastPage), id: "LastPage" },
                React.createElement(LastPage_1.default, null))));
    }
}
exports.PagerComponent = PagerComponent;
const connectedComponent = react_redux_1.connect(exports.mapStateToProps, exports.mapDispatchToProps)(PagerComponent);
exports.PagerWidget = connectedComponent;
//# sourceMappingURL=Pager.js.map